@@ -76,8 +76,7 @@ def dumps(obj, decimals=16):
     except KeyError:
         raise geomet.InvalidGeoJSONException('Invalid GeoJSON: %s' % obj)
 
-    fmt = '%%.%df' % decimals
-    result = exporter(obj, fmt)
+    result = exporter(obj, decimals)
     # Try to get the SRID from `meta.srid`
     meta_srid = obj.get('meta', {}).get('srid')
     # Also try to get it from `crs.properties.name`:
@@ -175,25 +174,52 @@ def _unsupported_geom_type(geom_type):
     raise ValueError("Unsupported geometry type '%s'" % geom_type)
 
 
-def _dump_point(obj, fmt):
+def _round_and_pad(value, decimals):
+    """
+    Round the input value to `decimals` places, and pad with 0's
+    if the resulting value is less than `decimals`.
+
+    :param value:
+        The value to round
+    :param decimals:
+        Number of decimals places which should be displayed after the rounding.
+    :return:
+        str of the rounded value
+    """
+    if isinstance(value, int) and decimals != 0:
+        # if we get an int coordinate and we have a non-zero value for
+        # `decimals`, we want to create a float to pad out.
+        value = float(value)
+
+    elif decimals == 0:
+        # if get a `decimals` value of 0, we want to return an int.
+        return repr(int(round(value, decimals)))
+
+    rounded = repr(round(value, decimals))
+    rounded += '0' * (decimals - len(rounded.split('.')[1]))
+    return rounded
+
+
+def _dump_point(obj, decimals):
     """
     Dump a GeoJSON-like Point object to WKT.
 
     :param dict obj:
         A GeoJSON-like `dict` representing a Point.
-    :param str fmt:
-        Format string which indicates the number of digits to display after the
+    :param int decimals:
+        int which indicates the number of digits to display after the
         decimal point when formatting coordinates.
 
     :returns:
         WKT representation of the input GeoJSON Point ``obj``.
     """
     coords = obj['coordinates']
-    pt = 'POINT (%s)' % ' '.join(fmt % c for c in coords)
+    pt = 'POINT (%s)' % ' '.join(_round_and_pad(c, decimals)
+                                 for c in coords)
     return pt
 
 
-def _dump_linestring(obj, fmt):
+def _dump_linestring(obj, decimals):
     """
     Dump a GeoJSON-like LineString object to WKT.
 
@@ -202,11 +228,12 @@ def _dump_linestring(obj, fmt):
     """
     coords = obj['coordinates']
     ls = 'LINESTRING (%s)'
-    ls %= ', '.join(' '.join(fmt % c for c in pt) for pt in coords)
+    ls %= ', '.join(' '.join(_round_and_pad(c, decimals)
+                             for c in pt) for pt in coords)
     return ls
 
 
-def _dump_polygon(obj, fmt):
+def _dump_polygon(obj, decimals):
     """
     Dump a GeoJSON-like Polygon object to WKT.
 
@@ -215,14 +242,15 @@ def _dump_polygon(obj, fmt):
     """
     coords = obj['coordinates']
     poly = 'POLYGON (%s)'
-    rings = (', '.join(' '.join(fmt % c for c in pt) for pt in ring)
+    rings = (', '.join(' '.join(_round_and_pad(c, decimals)
+                                for c in pt) for pt in ring)
              for ring in coords)
     rings = ('(%s)' % r for r in rings)
     poly %= ', '.join(rings)
     return poly
 
 
-def _dump_multipoint(obj, fmt):
+def _dump_multipoint(obj, decimals):
     """
     Dump a GeoJSON-like MultiPoint object to WKT.
 
@@ -231,14 +259,15 @@ def _dump_multipoint(obj, fmt):
     """
     coords = obj['coordinates']
     mp = 'MULTIPOINT (%s)'
-    points = (' '.join(fmt % c for c in pt) for pt in coords)
+    points = (' '.join(_round_and_pad(c, decimals)
+                       for c in pt) for pt in coords)
     # Add parens around each point.
     points = ('(%s)' % pt for pt in points)
     mp %= ', '.join(points)
     return mp
 
 
-def _dump_multilinestring(obj, fmt):
+def _dump_multilinestring(obj, decimals):
     """
     Dump a GeoJSON-like MultiLineString object to WKT.
 
@@ -247,13 +276,13 @@ def _dump_multilinestring(obj, fmt):
     """
     coords = obj['coordinates']
     mlls = 'MULTILINESTRING (%s)'
-    linestrs = ('(%s)' % ', '.join(' '.join(fmt % c for c in pt)
-                for pt in linestr) for linestr in coords)
+    linestrs = ('(%s)' % ', '.join(' '.join(_round_and_pad(c, decimals)
+                for c in pt) for pt in linestr) for linestr in coords)
     mlls %= ', '.join(ls for ls in linestrs)
     return mlls
 
 
-def _dump_multipolygon(obj, fmt):
+def _dump_multipolygon(obj, decimals):
     """
     Dump a GeoJSON-like MultiPolygon object to WKT.
 
@@ -273,7 +302,7 @@ def _dump_multipolygon(obj, fmt):
                 # and wrap in parens
                 '(%s)' % ', '.join(
                     # join coordinate values of a vertex
-                    ' '.join(fmt % c for c in pt)
+                    ' '.join(_round_and_pad(c, decimals) for c in pt)
                     for pt in ring)
                 for ring in poly)
             for poly in coords)
@@ -282,7 +311,7 @@ def _dump_multipolygon(obj, fmt):
     return mp
 
 
-def _dump_geometrycollection(obj, fmt):
+def _dump_geometrycollection(obj, decimals):
     """
     Dump a GeoJSON-like GeometryCollection object to WKT.
 
@@ -297,7 +326,7 @@ def _dump_geometrycollection(obj, fmt):
     geoms_wkt = []
     for geom in geoms:
         geom_type = geom['type']
-        geoms_wkt.append(_dumps_registry.get(geom_type)(geom, fmt))
+        geoms_wkt.append(_dumps_registry.get(geom_type)(geom, decimals))
     gc %= ','.join(geoms_wkt)
     return gc
 
